@@ -75,8 +75,8 @@ def partition_at_level(dendrogram, level):
 
     See Also
     --------
-    best_partition which directly combines partition_at_level and
-    generate_dendrogram to obtain the partition of highest modularity
+    best_partition : which directly combines partition_at_level and
+    generate_dendrogram : to obtain the partition of highest modularity
 
     Examples
     --------
@@ -127,9 +127,11 @@ def modularity(partition, graph, weight='weight'):
 
     Examples
     --------
-    >>> G=nx.erdos_renyi_graph(100, 0.01)
-    >>> part = best_partition(G)
-    >>> modularity(part, G)
+    >>> import community as community_louvain
+    >>> import networkx as nx
+    >>> G = nx.erdos_renyi_graph(100, 0.01)
+    >>> partition = community_louvain.best_partition(G)
+    >>> modularity(partition, G)
     """
     if graph.is_directed():
         raise TypeError("Bad graph type, use only non directed graph")
@@ -201,11 +203,11 @@ def best_partition(graph,
     Raises
     ------
     NetworkXError
-       If the graph is not Eulerian.
+       If the graph is not undirected.
 
     See Also
     --------
-    generate_dendrogram to obtain all the decompositions levels
+    generate_dendrogram : to obtain all the decompositions levels
 
     Notes
     -----
@@ -218,26 +220,29 @@ def best_partition(graph,
 
     Examples
     --------
-    >>>  #Basic usage
-    >>> G=nx.erdos_renyi_graph(100, 0.01)
-    >>> part = best_partition(G)
+    >>> # basic usage
+    >>> import community as community_louvain
+    >>> import networkx as nx
+    >>> G = nx.erdos_renyi_graph(100, 0.01)
+    >>> partion = community_louvain.best_partition(G)
 
-    >>> #other example to display a graph with its community :
-    >>> #better with karate_graph() as defined in networkx examples
-    >>> #erdos renyi don't have true community structure
-    >>> G = nx.erdos_renyi_graph(30, 0.05)
-    >>> #first compute the best partition
-    >>> partition = community.best_partition(G)
-    >>>  #drawing
-    >>> size = float(len(set(partition.values())))
+    >>> # display a graph with its communities:
+    >>> # as Erdos-Renyi graphs don't have true community structure,
+    >>> # instead load the karate club graph
+    >>> import community as community_louvain
+    >>> import matplotlib.cm as cm
+    >>> import matplotlib.pyplot as plt
+    >>> import networkx as nx
+    >>> G = nx.karate_club_graph()
+    >>> # compute the best partition
+    >>> partition = community_louvain.best_partition(G)
+
+    >>> # draw the graph
     >>> pos = nx.spring_layout(G)
-    >>> count = 0.
-    >>> for com in set(partition.values()) :
-    >>>     count += 1.
-    >>>     list_nodes = [nodes for nodes in partition.keys()
-    >>>                                 if partition[nodes] == com]
-    >>>     nx.draw_networkx_nodes(G, pos, list_nodes, node_size = 20,
-                                    node_color = str(count / size))
+    >>> # color the nodes according to their partition
+    >>> cmap = cm.get_cmap('viridis', max(partition.values()) + 1)
+    >>> nx.draw_networkx_nodes(G, pos, partition.keys(), node_size=40,
+    >>>                        cmap=cmap, node_color=list(partition.values()))
     >>> nx.draw_networkx_edges(G, pos, alpha=0.5)
     >>> plt.show()
     """
@@ -416,18 +421,20 @@ def induced_graph(partition, graph, weight="weight"):
 def __renumber(dictionary):
     """Renumber the values of the dictionary from 0 to n
     """
-    count = 0
-    ret = dictionary.copy()
-    new_values = dict([])
+    values = set(dictionary.values())
+    target = set(range(len(values)))
 
-    for key in dictionary.keys():
-        value = dictionary[key]
-        new_value = new_values.get(value, -1)
-        if new_value == -1:
-            new_values[value] = count
-            new_value = count
-            count += 1
-        ret[key] = new_value
+    if values == target:
+        # no renumbering necessary
+        ret = dictionary.copy()
+    else:
+        # add the values that won't be renumbered
+        renumbering = dict(zip(target.intersection(values),
+                               target.intersection(values)))
+        # add the values that will be renumbered
+        renumbering.update(dict(zip(values.difference(target),
+                                    target.difference(values))))
+        ret = {k: renumbering[v] for k, v in dictionary.items()}
 
     return ret
 
@@ -477,15 +484,15 @@ def __one_level(graph, status, weight_key, resolution, random_state):
             com_node = status.node2com[node]
             degc_totw = status.gdegrees.get(node, 0.) / (status.total_weight * 2.)  # NOQA
             neigh_communities = __neighcom(node, graph, status, weight_key)
-            remove_cost = - resolution * neigh_communities.get(com_node,0) + \
-                (status.degrees.get(com_node, 0.) - status.gdegrees.get(node, 0.)) * degc_totw
+            remove_cost = - neigh_communities.get(com_node,0) + \
+                resolution * (status.degrees.get(com_node, 0.) - status.gdegrees.get(node, 0.)) * degc_totw
             __remove(node, com_node,
                      neigh_communities.get(com_node, 0.), status)
             best_com = com_node
             best_increase = 0
             for com, dnc in __randomize(neigh_communities.items(), random_state):
-                incr = remove_cost + resolution * dnc - \
-                       status.degrees.get(com, 0.) * degc_totw
+                incr = remove_cost + dnc - \
+                       resolution * status.degrees.get(com, 0.) * degc_totw
                 if incr > best_increase:
                     best_increase = incr
                     best_com = com
